@@ -10,6 +10,7 @@
 #'
 #' @return A `dm` object.
 #'
+#' @inheritParams financial_db_con
 #' @export
 #' @examplesIf dm:::dm_has_financial() && rlang::is_installed("DiagrammeR")
 #' dm_financial() %>%
@@ -17,13 +18,7 @@
 dm_financial <- function() {
   stopifnot(rlang::is_installed("RMariaDB"))
 
-  my_db <- DBI::dbConnect(
-    RMariaDB::MariaDB(),
-    username = "guest",
-    password = "relational",
-    dbname = "Financial_ijs",
-    host = "relational.fit.cvut.cz"
-  )
+  my_db <- financial_db_con()
 
   my_dm <-
     dm_from_src(my_db, learn_keys = FALSE) %>%
