@@ -64,6 +64,21 @@ dplyr::tbl
 #' @export
 dplyr::arrange
 
+#' @export
+dplyr::rows_insert
+
+#' @export
+dplyr::rows_update
+
+#' @export
+dplyr::rows_patch
+
+#' @export
+dplyr::rows_upsert
+
+#' @export
+dplyr::rows_delete
+
 #' @export
 tidyr::unite
 
