@@ -27,6 +27,7 @@ test_that("check_key() checks primary key properly?", {
   )
 
   # if {tidyselect} selects nothing
+  # cf. issue #360
   skip_if_remote_src()
   expect_dm_error(
     check_key(data_mcard(), starts_with("d")),
@@ -42,8 +43,6 @@ test_that("check_key() checks primary key properly?", {
 })
 
 test_that("check_subset() checks if tf_1$c1 column values are subset of tf_2$c2 properly?", {
-  # FIXME: Message about temporary table
-  skip_if_src("mssql")
   expect_silent(check_subset(data_mcard_1(), a, data_mcard_2(), a))
 })
 
